@@ -1,7 +1,7 @@
 """
 Type annotations for appsync service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/type_defs.html)
 
 Usage::
 
@@ -15,12 +15,12 @@ import sys
 from typing import IO, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import (
     ApiCacheStatusType,
     ApiCacheTypeType,
     ApiCachingBehaviorType,
+    AssociationStatusType,
     AuthenticationTypeType,
     ConflictDetectionTypeType,
     ConflictHandlerTypeType,
@@ -45,8 +45,11 @@ else:
 
 __all__ = (
     "AdditionalAuthenticationProviderTypeDef",
+    "ApiAssociationTypeDef",
     "ApiCacheTypeDef",
     "ApiKeyTypeDef",
+    "AssociateApiRequestRequestTypeDef",
+    "AssociateApiResponseTypeDef",
     "AuthorizationConfigTypeDef",
     "AwsIamConfigTypeDef",
     "CachingConfigTypeDef",
@@ -57,6 +60,8 @@ __all__ = (
     "CreateApiKeyResponseTypeDef",
     "CreateDataSourceRequestRequestTypeDef",
     "CreateDataSourceResponseTypeDef",
+    "CreateDomainNameRequestRequestTypeDef",
+    "CreateDomainNameResponseTypeDef",
     "CreateFunctionRequestRequestTypeDef",
     "CreateFunctionResponseTypeDef",
     "CreateGraphqlApiRequestRequestTypeDef",
@@ -69,19 +74,26 @@ __all__ = (
     "DeleteApiCacheRequestRequestTypeDef",
     "DeleteApiKeyRequestRequestTypeDef",
     "DeleteDataSourceRequestRequestTypeDef",
+    "DeleteDomainNameRequestRequestTypeDef",
     "DeleteFunctionRequestRequestTypeDef",
     "DeleteGraphqlApiRequestRequestTypeDef",
     "DeleteResolverRequestRequestTypeDef",
     "DeleteTypeRequestRequestTypeDef",
     "DeltaSyncConfigTypeDef",
+    "DisassociateApiRequestRequestTypeDef",
+    "DomainNameConfigTypeDef",
     "DynamodbDataSourceConfigTypeDef",
     "ElasticsearchDataSourceConfigTypeDef",
     "FlushApiCacheRequestRequestTypeDef",
     "FunctionConfigurationTypeDef",
+    "GetApiAssociationRequestRequestTypeDef",
+    "GetApiAssociationResponseTypeDef",
     "GetApiCacheRequestRequestTypeDef",
     "GetApiCacheResponseTypeDef",
     "GetDataSourceRequestRequestTypeDef",
     "GetDataSourceResponseTypeDef",
+    "GetDomainNameRequestRequestTypeDef",
+    "GetDomainNameResponseTypeDef",
     "GetFunctionRequestRequestTypeDef",
     "GetFunctionResponseTypeDef",
     "GetGraphqlApiRequestRequestTypeDef",
@@ -99,27 +111,22 @@ __all__ = (
     "LambdaAuthorizerConfigTypeDef",
     "LambdaConflictHandlerConfigTypeDef",
     "LambdaDataSourceConfigTypeDef",
-    "ListApiKeysRequestListApiKeysPaginateTypeDef",
     "ListApiKeysRequestRequestTypeDef",
     "ListApiKeysResponseTypeDef",
-    "ListDataSourcesRequestListDataSourcesPaginateTypeDef",
     "ListDataSourcesRequestRequestTypeDef",
     "ListDataSourcesResponseTypeDef",
-    "ListFunctionsRequestListFunctionsPaginateTypeDef",
+    "ListDomainNamesRequestRequestTypeDef",
+    "ListDomainNamesResponseTypeDef",
     "ListFunctionsRequestRequestTypeDef",
     "ListFunctionsResponseTypeDef",
-    "ListGraphqlApisRequestListGraphqlApisPaginateTypeDef",
     "ListGraphqlApisRequestRequestTypeDef",
     "ListGraphqlApisResponseTypeDef",
-    "ListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef",
     "ListResolversByFunctionRequestRequestTypeDef",
     "ListResolversByFunctionResponseTypeDef",
-    "ListResolversRequestListResolversPaginateTypeDef",
     "ListResolversRequestRequestTypeDef",
     "ListResolversResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
-    "ListTypesRequestListTypesPaginateTypeDef",
     "ListTypesRequestRequestTypeDef",
     "ListTypesResponseTypeDef",
     "LogConfigTypeDef",
@@ -143,6 +150,8 @@ __all__ = (
     "UpdateApiKeyResponseTypeDef",
     "UpdateDataSourceRequestRequestTypeDef",
     "UpdateDataSourceResponseTypeDef",
+    "UpdateDomainNameRequestRequestTypeDef",
+    "UpdateDomainNameResponseTypeDef",
     "UpdateFunctionRequestRequestTypeDef",
     "UpdateFunctionResponseTypeDef",
     "UpdateGraphqlApiRequestRequestTypeDef",
@@ -165,6 +174,17 @@ AdditionalAuthenticationProviderTypeDef = TypedDict(
     total=False,
 )
 
+ApiAssociationTypeDef = TypedDict(
+    "ApiAssociationTypeDef",
+    {
+        "domainName": str,
+        "apiId": str,
+        "associationStatus": AssociationStatusType,
+        "deploymentDetail": str,
+    },
+    total=False,
+)
+
 ApiCacheTypeDef = TypedDict(
     "ApiCacheTypeDef",
     {
@@ -189,6 +209,22 @@ ApiKeyTypeDef = TypedDict(
     total=False,
 )
 
+AssociateApiRequestRequestTypeDef = TypedDict(
+    "AssociateApiRequestRequestTypeDef",
+    {
+        "domainName": str,
+        "apiId": str,
+    },
+)
+
+AssociateApiResponseTypeDef = TypedDict(
+    "AssociateApiResponseTypeDef",
+    {
+        "apiAssociation": "ApiAssociationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredAuthorizationConfigTypeDef = TypedDict(
     "_RequiredAuthorizationConfigTypeDef",
     {
@@ -351,6 +387,36 @@ CreateDataSourceResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateDomainNameRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateDomainNameRequestRequestTypeDef",
+    {
+        "domainName": str,
+        "certificateArn": str,
+    },
+)
+_OptionalCreateDomainNameRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateDomainNameRequestRequestTypeDef",
+    {
+        "description": str,
+    },
+    total=False,
+)
+
+
+class CreateDomainNameRequestRequestTypeDef(
+    _RequiredCreateDomainNameRequestRequestTypeDef, _OptionalCreateDomainNameRequestRequestTypeDef
+):
+    pass
+
+
+CreateDomainNameResponseTypeDef = TypedDict(
+    "CreateDomainNameResponseTypeDef",
+    {
+        "domainNameConfig": "DomainNameConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateFunctionRequestRequestTypeDef = TypedDict(
     "_RequiredCreateFunctionRequestRequestTypeDef",
     {
@@ -367,6 +433,7 @@ _OptionalCreateFunctionRequestRequestTypeDef = TypedDict(
         "requestMappingTemplate": str,
         "responseMappingTemplate": str,
         "syncConfig": "SyncConfigTypeDef",
+        "maxBatchSize": int,
     },
     total=False,
 )
@@ -440,6 +507,7 @@ _OptionalCreateResolverRequestRequestTypeDef = TypedDict(
         "pipelineConfig": "PipelineConfigTypeDef",
         "syncConfig": "SyncConfigTypeDef",
         "cachingConfig": "CachingConfigTypeDef",
+        "maxBatchSize": int,
     },
     total=False,
 )
@@ -517,6 +585,13 @@ DeleteDataSourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteDomainNameRequestRequestTypeDef = TypedDict(
+    "DeleteDomainNameRequestRequestTypeDef",
+    {
+        "domainName": str,
+    },
+)
+
 DeleteFunctionRequestRequestTypeDef = TypedDict(
     "DeleteFunctionRequestRequestTypeDef",
     {
@@ -559,6 +634,25 @@ DeltaSyncConfigTypeDef = TypedDict(
     total=False,
 )
 
+DisassociateApiRequestRequestTypeDef = TypedDict(
+    "DisassociateApiRequestRequestTypeDef",
+    {
+        "domainName": str,
+    },
+)
+
+DomainNameConfigTypeDef = TypedDict(
+    "DomainNameConfigTypeDef",
+    {
+        "domainName": str,
+        "description": str,
+        "certificateArn": str,
+        "appsyncDomainName": str,
+        "hostedZoneId": str,
+    },
+    total=False,
+)
+
 _RequiredDynamodbDataSourceConfigTypeDef = TypedDict(
     "_RequiredDynamodbDataSourceConfigTypeDef",
     {
@@ -610,10 +704,26 @@ FunctionConfigurationTypeDef = TypedDict(
         "responseMappingTemplate": str,
         "functionVersion": str,
         "syncConfig": "SyncConfigTypeDef",
+        "maxBatchSize": int,
     },
     total=False,
 )
 
+GetApiAssociationRequestRequestTypeDef = TypedDict(
+    "GetApiAssociationRequestRequestTypeDef",
+    {
+        "domainName": str,
+    },
+)
+
+GetApiAssociationResponseTypeDef = TypedDict(
+    "GetApiAssociationResponseTypeDef",
+    {
+        "apiAssociation": "ApiAssociationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetApiCacheRequestRequestTypeDef = TypedDict(
     "GetApiCacheRequestRequestTypeDef",
     {
@@ -645,6 +755,21 @@ GetDataSourceResponseTypeDef = TypedDict(
     },
 )
 
+GetDomainNameRequestRequestTypeDef = TypedDict(
+    "GetDomainNameRequestRequestTypeDef",
+    {
+        "domainName": str,
+    },
+)
+
+GetDomainNameResponseTypeDef = TypedDict(
+    "GetDomainNameResponseTypeDef",
+    {
+        "domainNameConfig": "DomainNameConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetFunctionRequestRequestTypeDef = TypedDict(
     "GetFunctionRequestRequestTypeDef",
     {
@@ -823,28 +948,6 @@ LambdaDataSourceConfigTypeDef = TypedDict(
     },
 )
 
-_RequiredListApiKeysRequestListApiKeysPaginateTypeDef = TypedDict(
-    "_RequiredListApiKeysRequestListApiKeysPaginateTypeDef",
-    {
-        "apiId": str,
-    },
-)
-_OptionalListApiKeysRequestListApiKeysPaginateTypeDef = TypedDict(
-    "_OptionalListApiKeysRequestListApiKeysPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListApiKeysRequestListApiKeysPaginateTypeDef(
-    _RequiredListApiKeysRequestListApiKeysPaginateTypeDef,
-    _OptionalListApiKeysRequestListApiKeysPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListApiKeysRequestRequestTypeDef = TypedDict(
     "_RequiredListApiKeysRequestRequestTypeDef",
     {
@@ -876,28 +979,6 @@ ListApiKeysResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListDataSourcesRequestListDataSourcesPaginateTypeDef = TypedDict(
-    "_RequiredListDataSourcesRequestListDataSourcesPaginateTypeDef",
-    {
-        "apiId": str,
-    },
-)
-_OptionalListDataSourcesRequestListDataSourcesPaginateTypeDef = TypedDict(
-    "_OptionalListDataSourcesRequestListDataSourcesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListDataSourcesRequestListDataSourcesPaginateTypeDef(
-    _RequiredListDataSourcesRequestListDataSourcesPaginateTypeDef,
-    _OptionalListDataSourcesRequestListDataSourcesPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListDataSourcesRequestRequestTypeDef = TypedDict(
     "_RequiredListDataSourcesRequestRequestTypeDef",
     {
@@ -929,27 +1010,23 @@ ListDataSourcesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListFunctionsRequestListFunctionsPaginateTypeDef = TypedDict(
-    "_RequiredListFunctionsRequestListFunctionsPaginateTypeDef",
+ListDomainNamesRequestRequestTypeDef = TypedDict(
+    "ListDomainNamesRequestRequestTypeDef",
     {
-        "apiId": str,
-    },
-)
-_OptionalListFunctionsRequestListFunctionsPaginateTypeDef = TypedDict(
-    "_OptionalListFunctionsRequestListFunctionsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "nextToken": str,
+        "maxResults": int,
     },
     total=False,
 )
 
-
-class ListFunctionsRequestListFunctionsPaginateTypeDef(
-    _RequiredListFunctionsRequestListFunctionsPaginateTypeDef,
-    _OptionalListFunctionsRequestListFunctionsPaginateTypeDef,
-):
-    pass
-
+ListDomainNamesResponseTypeDef = TypedDict(
+    "ListDomainNamesResponseTypeDef",
+    {
+        "domainNameConfigs": List["DomainNameConfigTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
 
 _RequiredListFunctionsRequestRequestTypeDef = TypedDict(
     "_RequiredListFunctionsRequestRequestTypeDef",
@@ -982,14 +1059,6 @@ ListFunctionsResponseTypeDef = TypedDict(
     },
 )
 
-ListGraphqlApisRequestListGraphqlApisPaginateTypeDef = TypedDict(
-    "ListGraphqlApisRequestListGraphqlApisPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListGraphqlApisRequestRequestTypeDef = TypedDict(
     "ListGraphqlApisRequestRequestTypeDef",
     {
@@ -1008,29 +1077,6 @@ ListGraphqlApisResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef = TypedDict(
-    "_RequiredListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef",
-    {
-        "apiId": str,
-        "functionId": str,
-    },
-)
-_OptionalListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef = TypedDict(
-    "_OptionalListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef(
-    _RequiredListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef,
-    _OptionalListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListResolversByFunctionRequestRequestTypeDef = TypedDict(
     "_RequiredListResolversByFunctionRequestRequestTypeDef",
     {
@@ -1064,29 +1110,6 @@ ListResolversByFunctionResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListResolversRequestListResolversPaginateTypeDef = TypedDict(
-    "_RequiredListResolversRequestListResolversPaginateTypeDef",
-    {
-        "apiId": str,
-        "typeName": str,
-    },
-)
-_OptionalListResolversRequestListResolversPaginateTypeDef = TypedDict(
-    "_OptionalListResolversRequestListResolversPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListResolversRequestListResolversPaginateTypeDef(
-    _RequiredListResolversRequestListResolversPaginateTypeDef,
-    _OptionalListResolversRequestListResolversPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListResolversRequestRequestTypeDef = TypedDict(
     "_RequiredListResolversRequestRequestTypeDef",
     {
@@ -1134,29 +1157,6 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListTypesRequestListTypesPaginateTypeDef = TypedDict(
-    "_RequiredListTypesRequestListTypesPaginateTypeDef",
-    {
-        "apiId": str,
-        "format": TypeDefinitionFormatType,
-    },
-)
-_OptionalListTypesRequestListTypesPaginateTypeDef = TypedDict(
-    "_OptionalListTypesRequestListTypesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListTypesRequestListTypesPaginateTypeDef(
-    _RequiredListTypesRequestListTypesPaginateTypeDef,
-    _OptionalListTypesRequestListTypesPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListTypesRequestRequestTypeDef = TypedDict(
     "_RequiredListTypesRequestRequestTypeDef",
     {
@@ -1292,6 +1292,7 @@ ResolverTypeDef = TypedDict(
         "pipelineConfig": "PipelineConfigTypeDef",
         "syncConfig": "SyncConfigTypeDef",
         "cachingConfig": "CachingConfigTypeDef",
+        "maxBatchSize": int,
     },
     total=False,
 )
@@ -1448,6 +1449,35 @@ UpdateDataSourceResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateDomainNameRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateDomainNameRequestRequestTypeDef",
+    {
+        "domainName": str,
+    },
+)
+_OptionalUpdateDomainNameRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateDomainNameRequestRequestTypeDef",
+    {
+        "description": str,
+    },
+    total=False,
+)
+
+
+class UpdateDomainNameRequestRequestTypeDef(
+    _RequiredUpdateDomainNameRequestRequestTypeDef, _OptionalUpdateDomainNameRequestRequestTypeDef
+):
+    pass
+
+
+UpdateDomainNameResponseTypeDef = TypedDict(
+    "UpdateDomainNameResponseTypeDef",
+    {
+        "domainNameConfig": "DomainNameConfigTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredUpdateFunctionRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateFunctionRequestRequestTypeDef",
     {
@@ -1465,6 +1495,7 @@ _OptionalUpdateFunctionRequestRequestTypeDef = TypedDict(
         "requestMappingTemplate": str,
         "responseMappingTemplate": str,
         "syncConfig": "SyncConfigTypeDef",
+        "maxBatchSize": int,
     },
     total=False,
 )
@@ -1538,6 +1569,7 @@ _OptionalUpdateResolverRequestRequestTypeDef = TypedDict(
         "pipelineConfig": "PipelineConfigTypeDef",
         "syncConfig": "SyncConfigTypeDef",
         "cachingConfig": "CachingConfigTypeDef",
+        "maxBatchSize": int,
     },
     total=False,
 )
